@@ -41,25 +41,6 @@ $(function() {
 		// WebSockets is supported
 		console.info("websockets supported");
 
-		window.ws = new WebSocket('ws://' + window.location.host + '/websocket');
-
-		ws.onopen = function () { 
-			console.info("WebSocket connection opened");
-
-			// Add an empty one editor tab on startup
-			AddEditorTab();
-		};
-
-		ws.onmessage = function(e) {
-			var message = messages.pop();
-			if(message.callback) {
-				var data = JSON.parse(e.data);
-				message.callback(data);
-			}
-		};
-		ws.onclose = function(e) {
-			console.info("WebSocket connection closed");
-		}
 
 		// Bug workaround: Firefox escape key kills the websocket connection...
 		if(navigator.userAgent.indexOf("Firefox") != -1) {
@@ -72,9 +53,66 @@ $(function() {
 			});	
 		}
 
+		var firstTime = true;
+		var connectWebSocket = function() {
+			// Connect
+			window.ws = new WebSocket('ws://' + window.location.host + '/websocket');
+
+			// Called once when the websocket connection is opened
+			ws.onopen = function () { 
+				// Change connection status to connected green
+				$("#connection-status")
+					.text("Connected")
+					.addClass("btn-success")
+					.removeClass("btn-danger");
+	
+				if(firstTime) {
+					// Add an empty one editor tab on startup
+					AddEditorTab();
+					firstTime = false;
+				}
+			};
+
+			// Called when the websocket message arrives
+			ws.onmessage = function(e) {
+				var message = messages.pop();
+				if(message.callback) {
+					var data = JSON.parse(e.data);
+					message.callback(data);
+				}
+			};
+
+			// Called once when the websocket connection is closed
+			ws.onclose = function(e) {
+
+				// Change connection status to closed red
+				$("#connection-status")
+					.text("Closed")
+					.addClass("btn-danger")
+					.removeClass("btn-success");
+				
+				// Cleanup old websocket connection
+				if(window.ws) {
+					window.ws.close();
+				}
+
+				// Reconnect...
+				setTimeout(connectWebSocket, 500);
+			};
+		};
+
+		// Connect websocket connection
+		connectWebSocket();
+
 	} else {
 		// No WebSockets support
 		alert("WebSockets is not supported here!\nBrowser: " + navigator.userAgent);
+
+		// Change connection status to unsupported red
+		$("#connection-status")
+			.text("Unsupported")
+			.addClass("btn-danger")
+			.removeClass("btn-success");
 	}
 	//--- Websockets support
 
