@@ -34,42 +34,34 @@ $(function() {
 		$("#ok-button", $actionsDialog).attr("disabled","disabled");
 
 		// Submit a POST request to find action
-		$.ajax({
-			type:    "POST",
-			url:     "/find-action",
-			data:    { "action": action },
-			success: function(matches) {
+		window.sendMessage("find-action", { "action": action }, function(matches) {
 				
-				// process matches and make select list html
-				var html = '';
-				for(var i = 0; i < matches.length; i++) {
-					var a = matches[i];
-					html += "<option id='" + a.id + "' "  + 
-						((i == 0) ? "selected" : "") + 
-						' help="' + a.help + '"' +
-						">" + 
-						a.name + 
-						"</option>";
-				}
-				
-				if(matches.length > 0) {
-					// One or more matches, remove OK button disabled state
-					$("#ok-button", $actionsDialog).removeAttr("disabled");
-				}
-				
-				// Render HTML
-				$("#matched-actions", $actionsDialog).html(html);
-
-				// On each selection change in the matched actions list, display the correspoding help text
-				$("#matched-actions", $actionsDialog).change(function() {
-					$("#action-help-text", $actionsDialog).html($("#matched-actions :selected", $actionsDialog).attr("help") );
-				});
-			},
-			error:   function(jqXHR, textStatus, errorThrown) {
-				console.error("Error:\n" + textStatus + "\n" + errorThrown);
+			// process matches and make select list html
+			var html = '';
+			for(var i = 0; i < matches.length; i++) {
+				var a = matches[i];
+				html += "<option id='" + a.id + "' "  + 
+					((i == 0) ? "selected" : "") + 
+					' help="' + a.help + '"' +
+					">" + 
+					a.name + 
+					"</option>";
 			}
+			
+			if(matches.length > 0) {
+				// One or more matches, remove OK button disabled state
+				$("#ok-button", $actionsDialog).removeAttr("disabled");
+			}
+			
+			// Render HTML
+			$("#matched-actions", $actionsDialog).html(html);
+
+			// On each selection change in the matched actions list, display the correspoding help text
+			$("#matched-actions", $actionsDialog).change(function() {
+				$("#action-help-text", $actionsDialog).html($("#matched-actions :selected", $actionsDialog).attr("help") );
+			});
 		});
-	}
+	};
 
 	// Handle double click event on the matched actions list as an action trigger
 	$("#matched-actions", $actionsDialog).dblclick(function() {
@@ -86,10 +78,8 @@ $(function() {
 	});
 	
 	// Find action on each action name text field change
-	var findActionTimeoutId;
 	$("#action-name", $actionsDialog).on('input', function() {
-		clearTimeout(findActionTimeoutId);
-		findActionTimeoutId = setTimeout(findAction, 250);
+		findAction();
 	});
 	
 	// Action dialog global key up handler
